@@ -4,7 +4,14 @@ import asyncio
 import contextlib
 import os
 
-from cb_events import AuthError, Event, EventClient, EventClientConfig, EventRouter, EventType
+from cb_events import (
+    AuthError,
+    Event,
+    EventClient,
+    EventClientConfig,
+    EventRouter,
+    EventType,
+)
 
 
 async def main() -> None:
