@@ -11,7 +11,7 @@ import logging
 from collections.abc import AsyncIterator
 from http import HTTPStatus
 from types import TracebackType
-from typing import Any, Self
+from typing import Any, ClassVar, Self
 
 from aiohttp import ClientSession, ClientTimeout
 from aiohttp_retry import ExponentialRetry, RetryClient
@@ -21,15 +21,13 @@ from .config import EventClientConfig
 from .constants import (
     AUTH_ERROR_STATUSES,
     BASE_URL,
-    CLOUDFLARE_CONNECTION_TIMEOUT,
-    CLOUDFLARE_ORIGIN_UNREACHABLE,
-    CLOUDFLARE_TIMEOUT_OCCURRED,
-    CLOUDFLARE_WEB_SERVER_DOWN,
+    CLOUDFLARE_ERROR_CODES,
     RATE_LIMIT_MAX_RATE,
     RATE_LIMIT_TIME_PERIOD,
     TESTBED_URL,
     TIMEOUT_ERROR_INDICATOR,
     TOKEN_MASK_LENGTH,
+    URL_TEMPLATE,
 )
 from .exceptions import AuthError, EventsError
 from .models import Event
@@ -54,6 +52,9 @@ class EventClient:
         retry_client: Retry-enabled HTTP client wrapper.
     """
 
+    _rate_limiters: ClassVar[dict[str, AsyncLimiter]] = {}
+    """Shared rate limiters per username to handle event loop reuse."""
+
     def __init__(
         self,
         username: str,
@@ -80,35 +81,32 @@ class EventClient:
         self.username = username.strip()
         self.token = token.strip()
 
-        # Use provided config or defaults
         self.config = config if config is not None else EventClientConfig()
         self.timeout = self.config.timeout
         self.base_url = TESTBED_URL if self.config.use_testbed else BASE_URL
         self.session: ClientSession | None = None
         self.retry_client: RetryClient | None = None
         self._next_url: str | None = None
-        self._rate_limiter = AsyncLimiter(
-            max_rate=RATE_LIMIT_MAX_RATE, time_period=RATE_LIMIT_TIME_PERIOD
-        )
+        if username not in EventClient._rate_limiters:
+            EventClient._rate_limiters[username] = AsyncLimiter(
+                max_rate=RATE_LIMIT_MAX_RATE, time_period=RATE_LIMIT_TIME_PERIOD
+            )
+        self._rate_limiter = EventClient._rate_limiters[username]
         self._closed = False
         self._lock = asyncio.Lock()
 
-        # Configure retry strategy
         self._retry_options = ExponentialRetry(
             attempts=self.config.retry_attempts,
             start_timeout=self.config.retry_backoff,
             max_timeout=self.config.retry_max_delay,
-            factor=self.config.retry_exponential_base,
+            factor=self.config.retry_factor,
             statuses={
                 HTTPStatus.INTERNAL_SERVER_ERROR,
                 HTTPStatus.BAD_GATEWAY,
                 HTTPStatus.SERVICE_UNAVAILABLE,
                 HTTPStatus.GATEWAY_TIMEOUT,
                 HTTPStatus.TOO_MANY_REQUESTS,
-                CLOUDFLARE_WEB_SERVER_DOWN,  # Cloudflare: Web Server Is Down
-                CLOUDFLARE_CONNECTION_TIMEOUT,  # Cloudflare: Connection Timed Out
-                CLOUDFLARE_ORIGIN_UNREACHABLE,  # Cloudflare: Origin Is Unreachable
-                CLOUDFLARE_TIMEOUT_OCCURRED,  # Cloudflare: A Timeout Occurred
+                *CLOUDFLARE_ERROR_CODES,
             },
         )
 
@@ -183,26 +181,12 @@ class EventClient:
         Returns:
             The URL to use for the next polling request.
         """
-        if self._next_url:
-            return self._next_url
-        return f"{self.base_url}/{self.username}/{self.token}/?timeout={self.timeout}"
-
-    def _handle_auth_error(self, status_code: int) -> None:
-        """Handle authentication errors from API responses.
-
-        Args:
-            status_code: The HTTP status code from the response.
-
-        Raises:
-            AuthError: If the status code indicates an authentication failure.
-        """
-        logger.warning(
-            "Authentication failed for user %s",
-            self.username,
-            extra={"status_code": status_code},
+        return self._next_url or URL_TEMPLATE.format(
+            base_url=self.base_url,
+            username=self.username,
+            token=self.token,
+            timeout=self.timeout,
         )
-        msg = f"Authentication failed for {self.username}"
-        raise AuthError(msg)
 
     def _extract_and_update_next_url(self, text: str) -> bool:
         """Extract nextUrl from timeout response and update internal state.
@@ -257,38 +241,32 @@ class EventClient:
             text = await resp.text()
             return resp.status, text
 
-    def _check_auth_error(self, status: int) -> None:
-        """Check for authentication errors and raise if found.
+    def _handle_response_status(self, status: int, text: str) -> bool:
+        """Handle response status codes and errors.
 
         Args:
             status: HTTP status code from the response.
-        """
-        if status in AUTH_ERROR_STATUSES:
-            self._handle_auth_error(status)
-
-    def _handle_timeout_response(self, status: int, text: str) -> bool:
-        """Handle timeout responses from the API.
-
-        Args:
-            status: HTTP status code from the response.
-            text: Response text containing potential error data with nextUrl.
+            text: Response text from the API.
 
         Returns:
-            True if timeout was handled and nextUrl extracted, False otherwise.
-        """
-        return status == HTTPStatus.BAD_REQUEST and self._extract_and_update_next_url(text)
-
-    @staticmethod
-    def _handle_error_response(status: int, text: str) -> None:
-        """Handle non-OK error responses from the API.
-
-        Args:
-            status: HTTP status code from the response.
-            text: Response text containing error information.
+            True if processing should continue, False if timeout was handled.
 
         Raises:
-            EventsError: For non-OK status codes with error details.
+            AuthError: For authentication failures.
+            EventsError: For other HTTP errors.
         """
+        if status in AUTH_ERROR_STATUSES:
+            logger.warning(
+                "Authentication failed for user %s",
+                self.username,
+                extra={"status_code": status},
+            )
+            msg = f"Authentication failed for {self.username}"
+            raise AuthError(msg)
+
+        if status == HTTPStatus.BAD_REQUEST and self._extract_and_update_next_url(text):
+            return False
+
         if status != HTTPStatus.OK:
             logger.error("HTTP error %d: %s", status, text[:200])
             msg = f"HTTP {status}: {text[:200]}"
@@ -298,23 +276,6 @@ class EventClient:
                 response_text=text,
             )
 
-    def _handle_response_status(self, status: int, text: str) -> bool:
-        """Handle response status codes.
-
-        Args:
-            status: HTTP status code from the response.
-            text: Response text from the API.
-
-        Returns:
-            True if processing should continue, False if timeout was handled.
-        """
-        self._check_auth_error(status)
-
-        if self._handle_timeout_response(status, text):
-            return False
-
-        self._handle_error_response(status, text)
-
         return True
 
     @staticmethod
