@@ -1,6 +1,7 @@
 """Exception classes for the Chaturbate Events client."""
 
 from .constants import RESPONSE_PREVIEW_LENGTH
+from .models import EventType
 
 
 class EventsError(Exception):
@@ -62,3 +63,32 @@ class AuthError(EventsError):
     sufficient permissions for the requested operation. This typically occurs
     with HTTP 401 (Unauthorized) or 403 (Forbidden) responses.
     """
+
+
+class RouterError(Exception):
+    """Custom exception for errors occurring in event handlers during dispatch.
+
+    Attributes:
+        message: Description of the error.
+        event_type: The type of event being processed when the error occurred.
+        handler_name: The name of the handler function where the error occurred.
+        original_error: The original exception that was raised.
+    """
+
+    def __init__(
+        self,
+        message: str,
+        event_type: EventType | None = None,
+        handler_name: str | None = None,
+    ) -> None:
+        """Initialize RouterError with context about the handler failure.
+
+        Args:
+            message: Description of the error.
+            event_type: The type of event being processed when the error occurred.
+            handler_name: The name of the handler function where the error occurred.
+        """
+        super().__init__(message)
+        self.message = message
+        self.event_type = event_type
+        self.handler_name = handler_name
