@@ -32,19 +32,16 @@ class EventType(StrEnum):
     registration with the EventRouter.
     """
 
-    # Broadcast state events
     BROADCAST_START = "broadcastStart"
     BROADCAST_STOP = "broadcastStop"
     ROOM_SUBJECT_CHANGE = "roomSubjectChange"
 
-    # User activity events
     USER_ENTER = "userEnter"
     USER_LEAVE = "userLeave"
     FOLLOW = "follow"
     UNFOLLOW = "unfollow"
     FANCLUB_JOIN = "fanclubJoin"
 
-    # Content events
     CHAT_MESSAGE = "chatMessage"
     PRIVATE_MESSAGE = "privateMessage"
     TIP = "tip"
@@ -120,7 +117,6 @@ class Message(BaseEventModel):
     color: str = Field(default="")
     font: str = Field(default="default")
     orig: str | None = Field(default=None)
-    # Private message specific fields
     from_user: str | None = Field(default=None, alias="fromUser")
     to_user: str | None = Field(default=None, alias="toUser")
 
@@ -132,7 +128,7 @@ class Message(BaseEventModel):
             True if this is a private message (has both from_user and to_user),
             False if this is a public chat message.
         """
-        return self.from_user is not None and self.to_user is not None
+        return bool(self.from_user and self.to_user)
 
 
 class Tip(BaseEventModel):
@@ -216,8 +212,9 @@ class Event(BaseEventModel):
             Message object if this is a message event with message data,
             otherwise None.
         """
-        message_types = {EventType.CHAT_MESSAGE, EventType.PRIVATE_MESSAGE}
-        if self.type in message_types and (message_data := self.data.get("message")):
+        if self.type in {EventType.CHAT_MESSAGE, EventType.PRIVATE_MESSAGE} and (
+            message_data := self.data.get("message")
+        ):
             return Message.model_validate(message_data)
         return None
 
