@@ -4,6 +4,7 @@ import logging
 from collections import defaultdict
 from collections.abc import Awaitable, Callable
 
+from .exceptions import RouterError
 from .models import Event, EventType
 
 logger = logging.getLogger(__name__)
@@ -17,19 +18,11 @@ class EventRouter:
     Provides decorator-based registration of async event handlers for specific
     event types or all events. Handlers are called in registration order when
     events are dispatched, allowing multiple handlers per event type.
-
-    Use the @router.on(EventType.X) decorator to register type-specific handlers,
-    or @router.on_any() to register handlers that receive all events.
-
-    Attributes:
-        _handlers: Dictionary mapping event type values to lists of handlers.
-        _global_handlers: List of handlers that receive all event types.
     """
 
     def __init__(self) -> None:
-        """Initialize the event router with empty handler registries."""
-        self._handlers: dict[str, list[EventHandler]] = defaultdict(list)
-        self._global_handlers: list[EventHandler] = []
+        """Initialize the event router with unified handler registry."""
+        self._handlers: dict[EventType | None, list[EventHandler]] = defaultdict(list)
 
     def on(self, event_type: EventType) -> Callable[[EventHandler], EventHandler]:
         """Register a handler for a specific event type.
@@ -52,10 +45,9 @@ class EventRouter:
                 async def handle_tip(event: Event) -> None:
                     print(f"Received tip: {event.tip.tokens} tokens")
         """
-        type_key = event_type.value
 
         def decorator(func: EventHandler) -> EventHandler:
-            self._handlers[type_key].append(func)
+            self._handlers[event_type].append(func)
             return func
 
         return decorator
@@ -79,7 +71,7 @@ class EventRouter:
         """
 
         def decorator(func: EventHandler) -> EventHandler:
-            self._global_handlers.append(func)
+            self._handlers[None].append(func)
             return func
 
         return decorator
@@ -87,19 +79,42 @@ class EventRouter:
     async def dispatch(self, event: Event) -> None:
         """Dispatch an event to all matching registered handlers.
 
-        Calls all registered handlers for the given event. Global handlers
-        (registered with on_any) are called first, followed by type-specific
-        handlers. All handlers are awaited in registration order.
+        All registered handlers are awaited sequentially.
 
         Args:
-            event: The event to dispatch to registered handlers.
+            event: The event to dispatch.
+
+        Raises:
+            RouterError: If any handler raises an exception, it is caught, logged,
+                and re-raised as a RouterError with context about the failure.
         """
+        all_handlers = [
+            *self._handlers[None],
+            *self._handlers[event.type],
+        ]
+
+        if not all_handlers:
+            return
+
         logger.debug(
             "Dispatching %s event to %d handlers",
             event.type.value,
-            len(self._global_handlers) + len(self._handlers.get(event.type.value, [])),
+            len(all_handlers),
         )
-        for handler in self._global_handlers:
-            await handler(event)
-        for handler in self._handlers.get(event.type.value, []):
-            await handler(event)
+
+        for handler in all_handlers:
+            try:
+                await handler(event)
+            except Exception as e:
+                handler_name = getattr(handler, "__name__", repr(handler))
+                logger.exception(
+                    "Error in handler %s for event type %s",
+                    handler_name,
+                    event.type.value,
+                )
+                msg = f"Error in handler {handler_name} for event type {event.type}"
+                raise RouterError(
+                    msg,
+                    event_type=event.type,
+                    handler_name=handler_name,
+                ) from e
