@@ -2,7 +2,8 @@
 
 import pytest
 
-from cb_events import AuthError, EventsError
+from cb_events import AuthError, EventsError, RouterError
+from cb_events.models import EventType
 
 
 class TestExceptions:
@@ -49,3 +50,16 @@ class TestExceptions:
     def test_error_messages(self, error_class, message):
         error = error_class(message)
         assert str(error) == message
+
+
+class TestRouterError:
+    def test_router_error_with_details(self):
+        error = RouterError(
+            "Handler execution failed",
+            event_type=EventType.TIP,
+            handler_name="handle_tip",
+        )
+
+        assert error.message == "Handler execution failed"
+        assert error.event_type == EventType.TIP
+        assert error.handler_name == "handle_tip"
